@@ -23,11 +23,11 @@ from google.protobuf.message import Message as GrpcMessage
 from dapr.proto import appcallback_service_v1, common_v1, appcallback_v1
 from dapr.clients.base import DEFAULT_JSON_CONTENT_TYPE
 from dapr.clients.grpc._request import InvokeMethodRequest, BindingRequest
-from dapr.clients.grpc._response import InvokeMethodResponse
+from dapr.clients.grpc._response import InvokeMethodResponse, TopicEventResponse
 
 InvokeMethodCallable = Callable[[
     InvokeMethodRequest], Union[str, bytes, InvokeMethodResponse]]
-TopicSubscribeCallable = Callable[[v1.Event], None]
+TopicSubscribeCallable = Callable[[v1.Event], Optional[TopicEventResponse]]
 BindingCallable = Callable[[BindingRequest], None]
 
 DELIMITER = ":"
@@ -77,9 +77,13 @@ class _CallbackServicer(appcallback_service_v1.AppCallbackServicer):
             topic: str,
             cb: TopicSubscribeCallable,
             metadata: Optional[Dict[str, str]],
-            rule: Optional[Rule] = None) -> None:
+            rule: Optional[Rule] = None,
+            disable_topic_validation: Optional[bool] = False) -> None:
         """Registers topic subscription for pubsub."""
-        topic_key = pubsub_name + DELIMITER + topic
+        if not disable_topic_validation:
+            topic_key = pubsub_name + DELIMITER + topic
+        else:
+            topic_key = pubsub_name
         pubsub_topic = topic_key + DELIMITER
         if rule is not None:
             path = getattr(cb, '__name__', rule.match)
@@ -170,10 +174,15 @@ class _CallbackServicer(appcallback_service_v1.AppCallbackServicer):
         """Subscribes events from Pubsub."""
         pubsub_topic = request.pubsub_name + DELIMITER + \
             request.topic + DELIMITER + request.path
+        no_validation_key = request.pubsub_name + DELIMITER + request.path
+
         if pubsub_topic not in self._topic_map:
-            context.set_code(grpc.StatusCode.UNIMPLEMENTED)  # type: ignore
-            raise NotImplementedError(
-                f'topic {request.topic} is not implemented!')
+            if no_validation_key in self._topic_map:
+                pubsub_topic = no_validation_key
+            else:
+                context.set_code(grpc.StatusCode.UNIMPLEMENTED)  # type: ignore
+                raise NotImplementedError(
+                    f'topic {request.topic} is not implemented!')
 
         event = v1.Event()
         event.SetEventType(request.type)
@@ -184,8 +193,9 @@ class _CallbackServicer(appcallback_service_v1.AppCallbackServicer):
 
         # TODO: add metadata from context to CE envelope
 
-        self._topic_map[pubsub_topic](event)
-
+        response = self._topic_map[pubsub_topic](event)
+        if isinstance(response, TopicEventResponse):
+            return appcallback_v1.TopicEventResponse(status=response.status.value)
         return empty_pb2.Empty()
 
     def ListInputBindings(self, request, context):
